function [res] = ConfigureSimulation_BC()
% Configure simulation of Balancing Cube (BC) model.
%
% --
% Supplementary material (simulation examples) to:
%   Distributed Event-based State Estimation (technical report)
%   Event-based State Estimation: An Emulation-based Approach (journal)
%
% Copyright 2015-17 Max Planck Society. All rights reserved.
% 
% Sebastian Trimpe
% Max Planck Institute for Intelligent Systems
% Autonomous Motion Department
% strimpe(at)tuebingen.mpg.de
%
% Revision history
% [26.07.15, ST]    first version, modified from 
%                   ConfigureSimulation_ThermoFluid.m
% [26.07.15, ST]    Allow for option to communicate with fixed period
% [31.07.15, ST]    Tuning of thresholds delta
% [03.08.15, ST]    some clean up


%% Configure simulation
% Which system?
%   2: Balancing Cube
res.ex = 2;    

% Some flags configuring simulation behavior
res.flag_randInitEst = 0;           % random initial estimates for agents
res.flag_generalDist = 1;           % general disturbance (defined in ConfigureSystem...)
res.flag_packetDrop = 1;            % packet drops (as per parameters below)
res.flag_syncAvg = 1;               % synchronous averaging

% Some more flags, used for development and debugging (otherwise, you
% probably don't want to change them).
res.flag_centralizedControl = 0;    % centralized control? (for debugging purposes)
res.flag_noNoise = 0;               % no process & measurement noise (for debugging)
res.flag_fullCommMeas = 0;          % full communication of measurements (if true, overwrites triggering decision)
res.flag_fullCommInputs = 0;        % full communication of inputs (if true, overwrites triggering decision)

res.flag_forcePeriodic = 0;         % force periodic sending, with fixed period res.forcedPeriod
res.forcedPeriod = nan;

% Random number generation
% Set seed to a positive integer to reproduce results.  If set to [], use
% "rng('shuffle')" to start with new seed every run.
res.seed = 25543;   % fixed (can be used to reproduce results from paper)
%res.seed = [];     % randomized


%% Parameters
% Set simulation parameter.
res.timeHorz = 4000;    % time horizon, number of simulation steps, []=samples
                        % Ts=0.01s -> 4000 samples = 40 sec    

% Packet drops inducing inter-agent errors
res.packetDrop.prob = 0.02;     % packet drop probability
